@@ -50,10 +50,10 @@ struct NcbProgressDialogPrivate
 
 	GtkWidget               *cancel_button;
 	GtkWidget               *close_button;
-	GtkWidget               *eject_button;
 	GtkWidget               *make_another_button;
 
 	gboolean                 confirm_cancel;
+	gboolean                 make_another_button_visible;
 
 	guint                    spin_id;
 };
@@ -348,8 +348,11 @@ dialog_sync_buttons (NcbProgressDialog *dialog,
 		gtk_widget_show (dialog->priv->close_button);
 		gtk_widget_hide (dialog->priv->cancel_button);
 
-		gtk_widget_show (dialog->priv->eject_button);
-		gtk_widget_show (dialog->priv->make_another_button);
+		if (dialog->priv->make_another_button_visible) {
+			gtk_widget_show (dialog->priv->make_another_button);
+		} else {
+			gtk_widget_hide (dialog->priv->make_another_button);
+		}
 
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 						 GTK_RESPONSE_CLOSE);
@@ -360,11 +363,21 @@ dialog_sync_buttons (NcbProgressDialog *dialog,
 		gtk_widget_hide (dialog->priv->close_button);
 		gtk_widget_show (dialog->priv->cancel_button);
 
-		gtk_widget_hide (dialog->priv->eject_button);
 		gtk_widget_hide (dialog->priv->make_another_button);
 	}
 }
 
+void
+ncb_progress_dialog_set_make_another_button_visible (NcbProgressDialog *dialog,
+						     gboolean           visible)
+{
+	g_return_if_fail (NCB_IS_PROGRESS_DIALOG (dialog));
+
+	dialog->priv->make_another_button_visible = visible;
+
+	dialog_sync_buttons (dialog, FALSE);
+}
+
 void
 ncb_progress_dialog_clear (NcbProgressDialog *dialog)
 {
@@ -422,7 +435,7 @@ vbox,
                             TRUE, TRUE, 0);
         gtk_widget_show_all (vbox);
 
-	dialog->priv->eject_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Eject"), GTK_RESPONSE_REJECT);
+	dialog->priv->make_another_button_visible = TRUE;
 	dialog->priv->make_another_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Make Another Copy"), GTK_RESPONSE_ACCEPT);
 	dialog->priv->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	dialog->priv->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
